Documentation
¶
Overview ¶
Package godb2 implements a pure Go database/sql driver for IBM DB2. This driver uses the DRDA protocol to communicate with DB2 servers without requiring any CGO dependencies.
Index ¶
Constants ¶
const ( // Version is the current version of the go-db2 driver Version = "0.1.0" // DriverName is the name used to register the driver DriverName = "db2" // ProtocolVersion is the DRDA protocol version supported ProtocolVersion = "DRDA Version 5" )
Variables ¶
This section is empty.
Functions ¶
func GetVersion ¶
GetVersion returns the driver version information
func ValidateDSN ¶
ValidateDSN validates a connection string and returns helpful error messages.
Types ¶
type Config ¶
type Config struct {
Hostname string
Port int
Database string
Username string
Password string
Timeout time.Duration
SSL bool
}
Config holds the configuration for a DB2 connection.
type Driver ¶
type Driver struct {
// contains filtered or unexported fields
}
Driver implements the database/sql/driver.Driver interface.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
examples
|
|
|
advanced
command
|
|
|
basic
command
|
|
|
demo
command
|
|
|
Package protocol implements the DRDA (Distributed Relational Database Architecture) protocol for communicating with IBM DB2 servers.
|
Package protocol implements the DRDA (Distributed Relational Database Architecture) protocol for communicating with IBM DB2 servers. |
|
Package types provides DB2 data type conversions between Go and DB2 types.
|
Package types provides DB2 data type conversions between Go and DB2 types. |
Click to show internal directories.
Click to hide internal directories.